==> kdelibs-3.0.1.tar.bz2: kdelibs-3.0.1/common_texts.cpp <==
/* This file is part of the KDE libraries
    Copyright (C) 1997 Stephan Kulow (coolo@kde.org)

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/

/* This file contains several often used phrases to avoid double
   work. If you think, that a phrase belongs here, contact me
*/

i18n( "Configure");
i18n( "&Configure");
i18n( "Configuration");
i18n( "Modify");
i18n( "&Modify");
i18n( "Align");
i18n( "Page");
i18n( "Border");
i18n( "Orientation");
i18n( "Width");
i18n( "&Width");
i18n( "Height");
i18n( "&Height");
i18n( "Spacing");
i18n( "Horizontal");
i18n( "Vertical");
i18n( "Right");
i18n( "Left");
i18n( "Center");
i18n( "Top");
i18n( "Bottom");
i18n( "&Bottom");
i18n( "Move");
i18n( "Select all");
i18n( "Delete all");
i18n( "Clear all");
i18n( "Export");
i18n( "Import");
i18n( "Zoom");
i18n( "&Zoom");
i18n( "Error");
i18n( "Malformed URL");
i18n( "Charset:");
i18n( "Yes");
i18n( "No");
i18n( "Warning");
i18n( "Save a file");
i18n( "Contents");
i18n( "About");
i18n( "&About");
i18n( "A&bout...");
i18n( "Untitled");
i18n( "OK");
i18n( "&OK");
i18n( "On");
i18n( "Off");
i18n( "Cancel");
i18n( "&Cancel");
i18n( "Apply");
i18n( "&Apply");
i18n( "File");
i18n( "&Discard");
i18n( "Discard");
i18n( "&File");
i18n( "Help");
i18n( "&Help");
i18n( "Edit");
i18n( "&Edit");
i18n( "&Options");
i18n( "View");
i18n( "&View");
i18n( "E&xit");
i18n( "Quit");
i18n( "&Quit");
i18n( "Reload");
i18n( "Back");
i18n( "Copy");
i18n( "&Copy");
i18n( "Paste");
i18n( "&Paste");
i18n( "&New Window...");
i18n( "New &Window...");
i18n( "&New Window");
i18n( "New Game");
i18n( "&New Game");
i18n( "Open");
i18n( "Open a file");
i18n( "Open...");
i18n( "&Open...");
i18n( "Cut");
i18n( "&Cut");
i18n( "C&ut");
i18n( "Font");
i18n( "&Foreground Color");
i18n( "&Background Color");
i18n( "Save");
i18n( "&Save");
i18n( "Save As");
i18n( "Save as...");
i18n( "S&ave as...");
i18n( "Close");
i18n( "&Close");
i18n( "&Print...");
i18n( "Sorry");
i18n( "Options");
i18n( "Remove");
i18n( "Add");
i18n( "Change");
i18n( "Delete");
i18n( "&Delete");
i18n( "Clear");
i18n( "Italic");
i18n( "Roman");
i18n( "Undo");
i18n( "&Undo");
i18n( "Redo");
i18n( "&Redo");
i18n( "&Game");
i18n( "Information");
i18n( "Portrait");
i18n( "Landscape");
i18n( "locally connected"); // Qt bug
i18n( "Browse...");
i18n( "Stop");
i18n( "&Remove");
i18n( "&Properties...");
i18n( "Properties");
i18n( "&Start");
i18n( "St&op");
i18n( "Miscellaneous");
i18n( "Font Size");
i18n( "Fonts");
i18n( "&Fonts");
i18n( "&Reload");
i18n( "Files");
i18n( "Continue");
i18n( "Restore");
i18n( "Appearance");
i18n( "Print");
i18n( "Monday");
i18n( "Tuesday");
i18n( "Wednesday");
i18n( "Thursday");
i18n( "Friday");
i18n( "Saturday");
i18n( "Sunday");
i18n( "&Update");
// mok - removed "Layout" from here as it has to be translated in many different ways
//i18n( "Layout");
i18n( "Highscore");
i18n( "&New View");
i18n( "&Insert");
// (Rikkus) Removed << and >> for next and previous and put '+ " >>"' in
// kwizard.h - fixes translation ?
i18n( "&Next");
i18n( "&Previous");
i18n( "Replace");
i18n( "&Replace...");
i18n( "Insert");
i18n( "Default");
i18n( "&Defaults");
i18n( "&Contents");
i18n( "&About...");
i18n( "Open Recent");
i18n( "Open &Recent");
i18n( "&Find...");
i18n( "Find &Next");
i18n( "&Bookmarks");
i18n( "&Add Bookmark");
i18n( "&Edit Bookmarks...");
i18n( "&Tools");
i18n( "&Spelling...");
i18n( "Show &Menubar");
i18n( "Show &Toolbar");
i18n( "Show &Statusbar");
i18n( "Configure &Key Bindings...");
i18n( "&Preferences...");
i18n( "&Settings");
i18n( "Do not show this message again");
i18n("QAccel", "Escape");
i18n("QAccel", "Tab");
i18n("QAccel", "Backtab");
i18n("QAccel", "Backspace");
i18n("QAccel", "Return");
i18n("QAccel", "Enter");
i18n("QAccel", "Insert");
i18n("QAccel", "Delete");
i18n("QAccel", "Pause");
i18n("QAccel", "Print");
i18n("QAccel", "SysReq");
i18n("QAccel", "Home");
i18n("QAccel", "End");
i18n("QAccel", "Left");
i18n("QAccel", "Up");
i18n("QAccel", "Right");
i18n("QAccel", "Down");
i18n("QAccel", "Prior");
i18n("QAccel", "Next");
i18n("QAccel", "Shift");
i18n("QAccel", "Control");
i18n("QAccel", "Meta");
i18n("QAccel", "Alt");
i18n("QAccel", "CapsLock");
i18n("QAccel", "NumLock");
i18n("QAccel", "ScrollLock");
i18n("QAccel", "Space");
i18n("QAccel", "ParenLeft");
i18n("QAccel", "ParenRight");
i18n("QAccel", "Asterisk");
i18n("QAccel", "Plus");
i18n("QAccel", "Comma");
i18n("QAccel", "Minus");
i18n("QAccel", "Period");
i18n("QAccel", "Slash");
i18n("QAccel", "Colon");
i18n("QAccel", "Semicolon");
i18n("QAccel", "Less");
i18n("QAccel", "Equal");
i18n("QAccel", "Greater");
i18n("QAccel", "Question");
i18n("QAccel", "BracketLeft");
i18n("QAccel", "Backslash");
i18n("QAccel", "BracketRight");
i18n("QAccel", "AsciiCircum");
i18n("QAccel", "Underscore");
i18n("QAccel", "QuoteLeft");
i18n("QAccel", "BraceLeft");
i18n("QAccel", "BraceRight");
i18n("QAccel", "AsciiTilde");
i18n("QAccel", "PgUp");
i18n("QAccel", "PgDown");
i18n("QAccel", "Apostrophe");
i18n("QAccel", "Ampersand");
i18n("QAccel", "Exclam");
i18n("QAccel", "Dollar");
i18n("QAccel", "Percent");
i18n("QAccel", "Menu");
i18n("QAccel", "Help");
i18n("QAccel", "NumberSign");
i18n("Main Toolbar");

==> kdelibs-3.1.3a.tar.bz2: kdelibs-3.1.3a/common_texts.cpp <==
/* This file is part of the KDE libraries
    Copyright (C) 1997 Stephan Kulow (coolo@kde.org)

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public License
    along with this library; see the file COPYING.LIB.  If not, write to
    the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
    Boston, MA 02111-1307, USA.
*/

/* This file contains several often used phrases to avoid double
   work. If you think, that a phrase belongs here, contact me
*/

i18n( "Configure");
i18n( "&Configure");
i18n( "Configuration");
i18n( "Modify");
i18n( "&Modify");
i18n( "Align");
i18n( "Page");
i18n( "Border");
i18n( "Orientation");
i18n( "Width");
i18n( "&Width");
i18n( "Height");
i18n( "&Height");
i18n( "Spacing");
i18n( "Horizontal");
i18n( "Vertical");
i18n( "Right");
i18n( "Left");
i18n( "Center");
i18n( "Top");
i18n( "Bottom");
i18n( "&Bottom");
i18n( "Move");
i18n( "Select All");
i18n( "Delete All");
i18n( "Clear All");
i18n( "Export");
i18n( "Import");
i18n( "Zoom");
i18n( "&Zoom");
i18n( "Error");
i18n( "Malformed URL");
i18n( "Charset:");
i18n( "Yes");
i18n( "No");
i18n( "Warning");
i18n( "Save a file");
i18n( "Contents");
i18n( "About");
i18n( "&About");
i18n( "A&bout");
i18n( "Untitled");
i18n( "OK");
i18n( "&OK");
i18n( "On");
i18n( "Off");
i18n( "Cancel");
i18n( "&Cancel");
i18n( "Apply");
i18n( "&Apply");
i18n( "File");
i18n( "&Discard");
i18n( "Discard");
i18n( "&File");
i18n( "Help");
i18n( "&Help");
i18n( "Edit");
i18n( "&Edit");
i18n( "&Options");
i18n( "View");
i18n( "&View");
i18n( "E&xit");
i18n( "Quit");
i18n( "&Quit");
i18n( "Reload");
i18n( "Back");
i18n( "Copy");
i18n( "&Copy");
i18n( "Paste");
i18n( "&Paste");
i18n( "&New Window...");
i18n( "New &Window...");
i18n( "&New Window");
i18n( "New Game");
i18n( "&New Game");
i18n( "Open");
i18n( "Open a File");
i18n( "Open...");
i18n( "&Open...");
i18n( "Cut");
i18n( "&Cut");
i18n( "C&ut");
i18n( "Font");
i18n( "&Foreground Color");
i18n( "&Background Color");
i18n( "Save");
i18n( "&Save");
i18n( "Save As");
i18n( "Save As...");
i18n( "S&ave As...");
i18n( "Close");
i18n( "&Close");
i18n( "&Print...");
i18n( "Sorry");
i18n( "Options");
i18n( "Remove");
i18n( "Add");
i18n( "Change");
i18n( "Delete");
i18n( "&Delete");
i18n( "Clear");
i18n( "Italic");
i18n( "Roman");
i18n( "Undo");
i18n( "&Undo");
i18n( "Redo");
i18n( "&Redo");
i18n( "&Game");
i18n( "Information");
i18n( "Portrait");
i18n( "Landscape");
i18n( "locally connected"); // Qt bug
i18n( "Browse...");
i18n( "Stop");
i18n( "&Remove");
i18n( "&Properties...");
i18n( "Properties");
i18n( "&Start");
i18n( "St&op");
i18n( "Miscellaneous");
i18n( "Font Size");
i18n( "Fonts");
i18n( "&Fonts");
i18n( "&Reload");
i18n( "Files");
i18n( "Continue");
i18n( "Restore");
i18n( "Appearance");
i18n( "Print");
i18n( "Monday");
i18n( "Tuesday");
i18n( "Wednesday");
i18n( "Thursday");
i18n( "Friday");
i18n( "Saturday");
i18n( "Sunday");
i18n( "&Update");
// mok - removed "Layout" from here as it has to be translated in many different ways
//i18n( "Layout");
i18n( "Highscore");
i18n( "&New View");
i18n( "&Insert");
// (Rikkus) Removed << and >> for next and previous and put '+ " >>"' in
// kwizard.h - fixes translation ?
i18n( "&Next");
i18n( "&Previous");
i18n( "Replace");
i18n( "&Replace...");
i18n( "Insert");
i18n( "Default");
i18n( "&Defaults");
i18n( "&Contents");
i18n( "&About");
i18n( "Open Recent");
i18n( "Open &Recent");
i18n( "&Find...");
i18n( "Find &Next");
i18n( "&Bookmarks");
i18n( "&Add Bookmark");
i18n( "&Edit Bookmarks...");
i18n( "&Tools");
i18n( "&Spelling...");
i18n( "Show &Menubar");
i18n( "Show &Toolbar");
i18n( "Show &Statusbar");
i18n( "Configure &Key Bindings...");
i18n( "&Preferences...");
i18n( "&Settings");
i18n( "Do not show this message again");
i18n("QAccel", "Escape");
i18n("QAccel", "Tab");
i18n("QAccel", "Backtab");
i18n("QAccel", "Backspace");
i18n("QAccel", "Return");
i18n("QAccel", "Enter");
i18n("QAccel", "Insert");
i18n("QAccel", "Delete");
i18n("QAccel", "Pause");
i18n("QAccel", "Print");
i18n("QAccel", "SysReq");
i18n("QAccel", "Home");
i18n("QAccel", "End");
i18n("QAccel", "Left");
i18n("QAccel", "Up");
i18n("QAccel", "Right");
i18n("QAccel", "Down");
i18n("QAccel", "Prior");
i18n("QAccel", "Next");
i18n("QAccel", "Shift");
i18n("QAccel", "Control");
i18n("QAccel", "Meta");
i18n("QAccel", "Alt");
i18n("QAccel", "CapsLock");
i18n("QAccel", "NumLock");
i18n("QAccel", "ScrollLock");
i18n("QAccel", "Space");
i18n("QAccel", "ParenLeft");
i18n("QAccel", "ParenRight");
i18n("QAccel", "Asterisk");
i18n("QAccel", "Plus");
i18n("QAccel", "Comma");
i18n("QAccel", "Minus");
i18n("QAccel", "Period");
i18n("QAccel", "Slash");
i18n("QAccel", "Colon");
i18n("QAccel", "Semicolon");
i18n("QAccel", "Less");
i18n("QAccel", "Equal");
i18n("QAccel", "Greater");
i18n("QAccel", "Question");
i18n("QAccel", "BracketLeft");
i18n("QAccel", "Backslash");
i18n("QAccel", "BracketRight");
i18n("QAccel", "AsciiCircum");
i18n("QAccel", "Underscore");
i18n("QAccel", "QuoteLeft");
i18n("QAccel", "BraceLeft");
i18n("QAccel", "BraceRight");
i18n("QAccel", "AsciiTilde");
i18n("QAccel", "PgUp");
i18n("QAccel", "PgDown");
i18n("QAccel", "Apostrophe");
i18n("QAccel", "Ampersand");
i18n("QAccel", "Exclam");
i18n("QAccel", "Dollar");
i18n("QAccel", "Percent");
i18n("QAccel", "Menu");
i18n("QAccel", "Help");
i18n("QAccel", "NumberSign");
i18n("Main Toolbar");

//some font styles
i18n("font style", "Demibold");
i18n("font style", "Light");
i18n("font style", "Light Italic");
i18n("font style", "Demibold Italic");
i18n("font style", "Demi bold");
i18n("font style", "Demi bold Italic");
i18n("font style", "Oblique");
i18n("font style", "Book");
i18n("font style", "Book Oblique");

//fix KWin after 3.1
i18n("window operation", "Sticky");
i18n("window operation", "Un-Sticky");
